@@ -113,16 +113,23 @@ jobs:
     - {toolchain: gcc-9, target_arch: i386, kconfig: tinyconfig}
     - {toolchain: gcc-10, target_arch: i386, kconfig: tinyconfig}
   tests:
-    - {device: qemu-i386}
+    - {device: qemu-i386, parameters: {HELLO: WORLD}}
     - {device: qemu-i386, tests: [ltp-syscalls], sharding: 3}
+    - {device: qemu-i386, tests: [ltp-commands], sharding: 1, parameters: {HELLO: WORLD}}
 
 - tests:
     - {kernel: https://storage.tuxboot.com/arm64/Image, device: qemu-arm64, tests: [ltp-smoke]}
     - {kernel: https://storage.tuxboot.com/i386/bzImage, device: qemu-i386, tests: [ltp-smoke]}
     - {kernel: https://storage.tuxboot.com/mips64/vmlinux, device: qemu-mips64, tests: [ltp-smoke]}
     - {kernel: https://storage.tuxboot.com/ppc64/vmlinux, device: qemu-ppc64, tests: [ltp-smoke]}
-    - {kernel: https://storage.tuxboot.com/riscv64/Image, device: qemu-riscv64, tests: [ltp-smoke]}
-    - {kernel: https://storage.tuxboot.com/x86_64/bzImage, device: qemu-x86_64, tests: [ltp-smoke]}
+    - kernel: https://storage.tuxboot.com/riscv64/Image
+      device: qemu-riscv64
+      bios: https://storage.tuxboot.com/riscv64/fw_jump.elf
+      tests: [ltp-smoke]
+    - kernel: https://storage.tuxboot.com/x86_64/bzImage
+      device: qemu-x86_64
+      rootfs: https://storage.tuxboot.com/x86_64/rootfs.ext4.zst
+      tests: [ltp-smoke]
 """
 
 
