@@ -237,6 +237,7 @@ class Build(HeadersMixin):
     limit = attrib(default=0)
     no_cache = attrib(default=False)
     is_public = attrib(default=True)
+    callback = attrib(default=None)
 
     def __attrs_post_init__(self):
         if isinstance(self.kconfig, str):
@@ -304,6 +305,8 @@ class Build(HeadersMixin):
                 kernel_patch,
             ) = handle_patch(self.patch_series)
             patch[build_entry["kernel_patch_file"]] = kernel_patch
+        if self.callback is not None:
+            build_entry["callback"] = self.callback
         return (build_entry, patch)
 
     def verify_build_parameters(self):
@@ -574,6 +577,7 @@ class Plan(HeadersMixin):
                             rootfs=test.get("rootfs"),
                             tests=test.get("tests", []),
                             timeouts=test.get("timeouts"),
+                            callback=test.get("callback"),
                             wait_for=build.uid,
                         )
                     )
@@ -603,6 +607,7 @@ class Plan(HeadersMixin):
                             scp_romfw=test.get("scp_romfw"),
                             tests=test.get("tests", []),
                             timeouts=test.get("timeouts"),
+                            callback=test.get("callback"),
                         )
                     )
 
@@ -891,6 +896,7 @@ class Test(HeadersMixin):
     scp_romfw = attrib(default=None)
     tests = attrib(default=[])
     timeouts = attrib(default=[])
+    callback = attrib(default=None)
 
     uid = attrib(default=None)
     wait_for = attrib(default=None)
@@ -929,6 +935,8 @@ class Test(HeadersMixin):
             data["boot_args"] = self.boot_args
         if self.wait_for:
             data["waiting_for"] = self.wait_for
+        if self.callback:
+            data["callback"] = self.callback
         if plan is not None:
             data["plan"] = plan
 
@@ -1139,6 +1147,7 @@ class Bitbake(HeadersMixin):
         extraconfigs = attrib(default=[])
         pinned_manifest = attrib(default=None)
         is_public = attrib(default=True)
+        callback = attrib(default=None)
 
     def __attrs_post_init__(self):
         self.build_definition = self.BuildDefinition(**(self.data))
