@@ -66,6 +66,13 @@ def file_or_url(path):
     error(f"{path} does not exist or invalid")
 
 
+def is_url(path):
+    """Validate if path is an URL"""
+    if urlparse(path).scheme in ["http", "https"]:
+        return path
+    error(f"{path} is not a valid http(s) url")
+
+
 def wait_for_object(build_object):
     result = True
     for state in build_object.watch():
